# ----------------------- tidyverse -------------------------------------

#' @export
#' @importFrom magrittr "%>%"
magrittr::`%>%`

#' @export
#' @importFrom magrittr "%<>%"
magrittr::`%<>%`

#' @export
#' @importFrom magrittr "%$%"
magrittr::`%$%`

#' @export
#' @importFrom tibble tibble
tibble::tibble

#' @export
#' @importFrom tibble as_tibble
tibble::as_tibble

#' @export
#' @importFrom rlang "%||%"
rlang::`%||%`

#' @export
#' @importFrom rlang "%|%"
rlang::`%|%`
